// ShiftedComponent.h: interface for the ShiftedComponent class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_SHIFTEDCOMPONENT_H__200E0414_C93B_4380_8B5E_DCCEAFBB738C__INCLUDED_)
#define AFX_SHIFTEDCOMPONENT_H__200E0414_C93B_4380_8B5E_DCCEAFBB738C__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "Component.h"
#include "BasicComponent.h"

class ShiftedComponent : public Component  
{
public:
	void setVariant(ComponentVariant * var);
	void restoreVariant();
	void storeVariant();
	void loadVariants(BasicComponent * predecessor, BasicComponent * successor);
	void setVariants(long maxVariants);
	bool variantCheck(ShiftedComponent * sc);

	void getSize(long & xMin, long & xMax, long & yMin, long & yMax);
	void getMinimumSize(long & xMin, long & xMax, long & yMin, long & yMax);
	bool getCell(long x, long y);
	bool getUsage(long x, long y);
	virtual void print();
	ShiftedComponent();
	virtual ~ShiftedComponent();

	inline void setVariantNo(long no)
	{
		m_variant = m_variantList[no];
	}

	inline long getNumVariants()
	{
		return m_numVariants;
	}

	inline void init(BasicComponent * component, long sx, long sy, Direction sDirection)
	{
		m_component = component;
		m_sx = sx;
		m_sy = sy;
		m_sDirection = sDirection;
		m_dx = m_component->getDx(m_sDirection) + m_sx;
		m_dy = m_component->getDy(m_sDirection) + m_sy;
		m_direction = m_component->getDirection(m_sDirection);
	};

	inline long getSx() { return m_sx; };
	inline long getSy() { return m_sy; };
	inline long getDx() { return m_dx; };
	inline long getDy() { return m_dy; };
	inline Direction getSDirection() { return m_sDirection; };
	inline Direction getDirection() { return m_direction; };
	inline BasicComponent * getBasicComponent() { return m_component; };
	inline ComponentVariant * getVariant() { return m_variant; };
	inline ComponentVariant * getVariant(long no) { return m_variantList[no]; };

private:
	ComponentVariant * m_storedVariant;
	long m_numVariants;
	long m_sx;
	long m_sy;
	long m_dx;
	long m_dy;
	Direction m_sDirection;
	Direction m_direction;
	BasicComponent * m_component;
	ComponentVariant * m_variant;
	ComponentVariant ** m_variantList;
	long m_variantListLength;
};

#endif // !defined(AFX_SHIFTEDCOMPONENT_H__200E0414_C93B_4380_8B5E_DCCEAFBB738C__INCLUDED_)
